/*
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc.
 * All Rights Reserved.
 *-----------------------------------------------------------------------------
 * $Id: ResourceManagerEventListener.java,v 1.1 2002/02/13 23:36:46 cney Exp $
 *-----------------------------------------------------------------------------
 */
package org.objectweb.transaction.api;

/**
* This interface has been introduced to allow late enrolment of connections
* that are opened in the thread before the transaction starts.
* Resource Managers that support registration of <code>ResourceManagerEventListener</code>
* will be able to notify the transaction manager of connections opened
* without transaction context and get a callback from the transaction manager
* when the transaction begins.<BR>
* In a typical Resource Manager, the registration of the listener is made by
* the application server via mutator method such as
* <code>ResourceManager.setResourceManagerEventListener(listener)</code>
* @author Christophe Ney cney@batisseurs.com for Lutris Technologies
*/
public interface ResourceManagerEventListener {
    
    /**
     * This method is called by the resource manager when a <code>getConnection</code>
     * call is made without a transaction context. The <code>ResourceManagerEvent</code>
     * is to be used by the listener to keep track of those events and perform a late
     * enrolment of those logical connection when the transaction begins.
     * @param event event sent to the listener
     */
    public void connectionOpened(ResourceManagerEvent event);
    
    
    /**
     * This method is called by the resource manager when a logical connection that
     * was opened without transaction context is closed. It is to be used by the
     * listener to keep track of those events and perform clean-up.* @param event event sent to the listener
     */
    public void connectionClosed(ResourceManagerEvent event);
    
    /**
     * This method is called by the resource manager when a logical connection that
     * was opened without transaction context is about to throw an exception.
     * It is to be used by the listener to keep track of those events and perform
     * clean-up.
     * @param event event sent to the listener
     */
    public void connectionErrorOccured(ResourceManagerEvent event);
    
}
